@@ -343,7 +343,9 @@ class SanityCheck :
         for entry in self.fstab.other :
             if re.search("(^UUID=|^LABEL=|^/dev/)", entry["FSTAB_NAME"]) \
                 and entry["FSTAB_TYPE"] not in FstabData.ignore_fs \
-                and re.search("^/", entry["FSTAB_PATH"]) and not entry["FSTAB_NAME"] in known :
+                and entry["FSTAB_NAME"] not in FstabData.ignore_dev \
+                and re.search("^/", entry["FSTAB_PATH"]) \
+                and not entry["FSTAB_NAME"] in known :
                 unknow_block.append(entry)
         if unknow_block :
             dial = dialog("warning", _("Removing unknown devices from\nthe configuration file?"), \
