@@ -24,6 +24,7 @@ import sys
 import time
 import logging
 import threading
+from subprocess import Popen
 from xml.sax.saxutils import escape as escape_mkup
 
 import pygtk
@@ -86,7 +87,6 @@ except :
 from config import *
 from Config import Config
 from Dialogs import *
-from AddWizard import *
 from Fstab.FstabHandler import *
 
 gtk.glade.bindtextdomain("disk-manager",localedir)
@@ -104,13 +104,6 @@ class DiskManager(SimpleGladeApp) :
         # Start configuration
         self.conf = Config()
 
-        # Delete broken link, and create hal fdi directory if it don't exist
-        for value in (TARGET_NTFS_WRITE, TARGET_NTFS_READ) :
-            if not os.path.exists(value) and os.path.islink(value) :
-                os.unlink(value)
-        if not os.path.exists(HAL_CONFIG_DIR) :
-            os.mkdir(HAL_CONFIG_DIR)
-
         # Perform sanity check
         check = SanityCheck(parent = self.window_main, conf = self.conf)
         check.unknow()
@@ -121,32 +114,6 @@ class DiskManager(SimpleGladeApp) :
         backend = self.conf.get("General", "backend")
         self.disk = FstabHandler(FSTAB, naming = naming, backend = backend, \
                 parent = self.window_main, external_change_watch = True)
-
-        # Don't use ntfs-3g when we don't have it. Use it when we don't have ntfs
-        ntfs_driver = self.disk.info.get_drivers("ntfs")["all"].keys()
-        if not "ntfs-3g" in ntfs_driver :
-            self.vbox_ntfs.hide()
-            self.conf.set("General","ntfs_driver","ntfs")
-        elif not "ntfs" in ntfs_driver :
-            self.checkbutton_ntfs.set_active(True)
-            self.conf.set("General","ntfs_driver","ntfs-3g")
-            self.checkbutton_ntfs.set_sensitive(False)
-
-        # Set external NTFS policy. Set internal NTFS polcy for non mounted new devices
-        self.set_external_ntfs_policy(self.conf.get("General","ntfs_driver"))
-        if os.path.exists(TARGET_NTFS_WRITE) :
-            self.conf.set("General","ntfs_driver","ntfs-3g")
-            self.set_external_ntfs_policy("ntfs-3g")
-        driver = self.conf.get("General","ntfs_driver")
-        for entry in self.disk.get_new() :
-            if entry["FS_TYPE"] == "ntfs" and not entry["FSTAB_TYPE"] == driver \
-                and not entry.get_is_mounted() :
-                self.disk.set(entry, type = driver)
-    
-        #Disable notify if we can't show it :
-        if not TRAYTYPE :
-            self.conf.set("General","notify","False")
-            self.checkbutton_notify.set_sensitive(False)     
         
         # Draw stuff
         try :
@@ -159,7 +126,6 @@ class DiskManager(SimpleGladeApp) :
         self.width = self.conf.getint("Gui Config", "main_width")
         self.height = self.conf.getint("Gui Config", "main_width")
         self.window_main.show()
-        self.set_buttons()
         self.setupTreeView()
         self.update_main()
                 
@@ -168,9 +134,6 @@ class DiskManager(SimpleGladeApp) :
         self.conf.set("Detected Device", "detected", detected)
         
         # Connect events
-        self.checkbutton_ntfs.connect("toggled", self.on_ntfs_toggled)
-        self.checkbutton_notify.connect("toggled", self.on_notify_toggled)
-        self.ntfs_button.connect("clicked",  self.on_ntfs_toggled)
         self.quit_menu.connect("activate", self.on_close_clicked)
         self.window_main.connect("destroy", self.on_close_clicked)
         self.window_main.connect("configure-event", self.on_resize)
@@ -178,33 +141,14 @@ class DiskManager(SimpleGladeApp) :
         self.save_menu.connect("activate", self.on_save_clicked)
         self.history_menu.connect("activate", self.on_history_clicked)
         self.about_menu.connect("activate", about_dialog, self.window_main)
-        self.new_button.connect("clicked", self.on_new_clicked)
         self.edit_button.connect("clicked",  self.on_edit_clicked)
         self.mount_button.connect("clicked",  self.on_mount_clicked)
         self.info_button.connect("clicked", self.on_info_clicked)
         self.treeview.connect("row-activated", self.on_row_activated)
         self.treeview.connect("cursor_changed", self.on_cursor_changed)
         self.disk.connect("any_changed", gobject.idle_add, self.update_main)
-        
-        # Add some tooltip
-        gtk.Tooltips().set_tip(self.eventbox_total_avail, \
-        _("Available size can differ from free size\n"
-        "because some space may be reserved for the root user."))
-        
+                
         gtk.gdk.threads_init()
-
-    def set_buttons(self) :
-        ''' Set ntfs policy & notify button '''
-        
-        if self.conf.get("General","notify") == "True" :
-            self.checkbutton_notify.set_active(True)
-        if self.conf.get("General","ntfs_driver") == "ntfs-3g" \
-            and os.path.exists(TARGET_NTFS_WRITE):
-            self.checkbutton_ntfs.set_active(True)
-        elif self.conf.get("General","ntfs_driver") == "ntfs" \
-            and os.path.exists(TARGET_NTFS_READ) :
-            self.checkbutton_ntfs.set_active(False)
-        else : self.checkbutton_ntfs.set_inconsistent(True)
         
     def setupTreeView(self) :
         ''' treeview setup '''
@@ -284,20 +228,6 @@ class DiskManager(SimpleGladeApp) :
                     "selected_order").upper()))
         self.treeview.set_model(self.tree_store)
         
-    def set_external_ntfs_policy(self, driver) :
-        ''' Set external NTFS policy '''
-    
-        if driver =="ntfs-3g" :
-            if not os.path.exists(TARGET_NTFS_WRITE) :
-                os.symlink(NTFS_WRITE, TARGET_NTFS_WRITE)
-            if os.path.exists(TARGET_NTFS_READ) :
-                os.unlink(TARGET_NTFS_READ)   
-        else : 
-            if not os.path.exists(TARGET_NTFS_READ) :
-                os.symlink(NTFS_READ, TARGET_NTFS_READ)
-            if os.path.exists(TARGET_NTFS_WRITE) :
-                os.unlink(TARGET_NTFS_WRITE)
-
     def update_main(self) :
         ''' Update the window '''
     
@@ -308,22 +238,7 @@ class DiskManager(SimpleGladeApp) :
 
         self.undo_menu.set_sensitive(self.disk.original_has_changed())
         self.save_menu.set_sensitive(self.disk.lastsave_has_changed())
-            
-        self.hbuttonbox_ntfs.hide()
-        for i in self.disk.search("ntfs", keys = ["FS_TYPE"]) :
-            if not self.disk[i]["FSTAB_TYPE"] == self.conf.get("General","ntfs_driver") :
-                self.hbuttonbox_ntfs.show()
-                break
-
-        new_device = self.disk.get_new()
-        if new_device :
-            self.label_status_new.set_label(_("%i new partition(s) can be configured.") \
-                    % len(new_device))
-            self.hbuttonbox_new.show()
-        else : 
-            self.label_status_new.set_label(_("All partitions are configured"))
-            self.hbuttonbox_new.hide()
-            
+                        
         (self.total, self.total_free, self.total_used, self.total_avail) = (0,0,0,0)
         configured = self.disk.get_configured()
         self.tree_store.clear()
@@ -361,14 +276,7 @@ class DiskManager(SimpleGladeApp) :
                 per_use = 0
             self.tree_store.append((enable, sensitive, device, path, type, \
                     style, pix, size, free, used, per_use))
-                    
-        self.label_status_configured.set_label( \
-            _("%i partitions are in use. (total size : %s)") % \
-            (len(configured), size_renderer(self.total)))
-        self.label_status_free.set_label(size_renderer(self.total_free))
-        self.label_status_used.set_label(size_renderer(self.total_used))
-        self.label_status_avail.set_label(size_renderer(self.total_avail))
-                    
+                                        
         if focus_path :
             for path in range(len(self.tree_store)) :
                 l = self.tree_store[path]
@@ -399,38 +307,6 @@ class DiskManager(SimpleGladeApp) :
             return -1
         return 1
              
-    def on_ntfs_toggled(self, button) :
-        ''' Set NTFS policy corresponding to the button status '''
-        
-        self.checkbutton_ntfs.set_inconsistent(False)
-        if self.checkbutton_ntfs.get_active() : 
-            driver = "ntfs-3g"
-        else : 
-            driver = "ntfs"
-        self.disk.set_mode("delay")
-        for entry in self.disk.get_all() :
-            if entry["FS_TYPE"] == "ntfs" and not entry["FSTAB_TYPE"] == driver :
-                self.disk.set(entry, type = driver)
-        self.disk.set_mode("real")
-        self.set_external_ntfs_policy(driver)
-        self.conf.set("General","ntfs_driver",driver)
-        self.hbuttonbox_ntfs.hide()
-        for i in self.disk.search("ntfs", keys = ["FS_TYPE"]) :
-            if not self.disk[i]["FSTAB_TYPE"] == self.conf.get("General","ntfs_driver") :
-                self.hbuttonbox_ntfs.show()
-                break
-        
-    def on_notify_toggled(self, button) :
-        ''' Set notify corresponding to the button status '''
-    
-        self.conf.set("General","notify",self.checkbutton_notify.get_active())
-
-    def on_new_clicked(self, button) :
-        ''' Start configuration_wizard '''
-
-        app = AddWizard(parent = self.window_main, disk = self.disk, log = False)
-        app.run()
-
     def on_edit_clicked(self, button) :
 
         path = self.treeview.get_cursor()[0]
@@ -544,7 +420,8 @@ class DiskManager(SimpleGladeApp) :
         self.height = event.height
     
     def on_close_clicked(self, button) :
-        ''' Save the log when we close the app '''
+        ''' Save the log when we clo            AddWizard.py \
+se the app '''
 
         self.window_main.hide()
         while gtk.events_pending() :
@@ -557,106 +434,3 @@ class DiskManager(SimpleGladeApp) :
         self.conf.set("Gui Config", "main_height", self.height)
         self.disk.shutdown()
         gtk.main_quit()
-       
-               
-class Notification :
-    ''' Class that manage the notification '''
-   
-
-    def __init__(self) :
-    
-        if TRAYTYPE == "gtk" :
-            self.trayicon = gtk.status_icon_new_from_icon_name("disk-manager")
-            self.trayicon.connect("activate", self.open_wizard)
-            self.trayicon.connect( "popup-menu", self.on_popup_menu )
-            self.buildMenu()
-            self.trayicon.set_tooltip(_("New partitions detected"))
-            gtk.gdk.threads_init()
-            t = threading.Thread(target=self.start_notification)
-            t.start()
-            gtk.main()
-        elif TRAYTYPE == "egg" :
-            self.trayicon = egg.trayicon.TrayIcon("disk-manager")
-            self.eventbox = gtk.EventBox()
-            self.eventbox.set_events(gtk.gdk.BUTTON_PRESS_MASK)
-            self.eventbox.connect_object("button_press_event", self.iconclick, self.eventbox)
-            self.image = gtk.image_new_from_icon_name("disk-manager", gtk.ICON_SIZE_BUTTON)
-            self.tooltips = gtk.Tooltips()
-            self.tooltips.set_tip(self.eventbox, _("New partitions detected"))
-            self.eventbox.add(self.image)
-            self.trayicon.add(self.eventbox)
-            self.eventbox.show_all()
-            self.trayicon.show_all()
-            self.buildMenu()
-            gobject.timeout_add(2500, self.show_notify)
-            gtk.main()
-        else :
-            logging.warning("Notification is disabled")
-            
-    def start_notification(self) :
-    
-        for i in range(100) :
-            if self.trayicon.is_embedded() :
-                break
-            time.sleep(2)
-        gobject.timeout_add(2500, self.show_notify)
-            
-    def show_notify(self) :
-    
-        if not NOTIFICATION :
-            return
-        pynotify.init("disk-manager")
-        notify = pynotify.Notification(_("New partitions detected"),
-           _("New partitions have been detected and can be\n"
-             "configured by clicking on this icon."),"disk-manager")
-        if TRAYTYPE == "gtk" :
-            notify.attach_to_status_icon(self.trayicon)
-        else :
-            notify.attach_to_widget(self.trayicon)
-        notify.set_timeout(10000)
-        notify.show()
-        
-    def iconclick(self, widget, event):
-
-        if event.type == gtk.gdk.BUTTON_PRESS:
-            if event.button == 1:
-                self.open_wizard(self.eventbox)
-            elif event.button == 3: 
-                self.menu.popup(None, None, None, event.button, event.time)
-        
-    def buildMenu(self):
-
-        self.menu = gtk.Menu()
-        menuItem = gtk.MenuItem(_("Start configuration"))
-        menuItem.connect("activate", self.open_wizard)
-        self.menu.append(menuItem)
-        menuItem = gtk.MenuItem(_("Automatic configuration"))
-        menuItem.connect("activate", self.start_auto)
-        self.menu.append(menuItem)
-        self.menu.append( gtk.SeparatorMenuItem() )
-        menuItem = gtk.ImageMenuItem( gtk.STOCK_QUIT )
-        menuItem.connect("activate", self.on_quit)
-        self.menu.append(menuItem)
-        self.menu.show_all()
-        
-    def on_popup_menu( self, status_icon, button, activate_time ):
-    
-        self.menu.popup( None, None, None, button, activate_time )
-        
-    def on_quit(self, widget) :
-    
-        gtk.main_quit()
-        
-    def start_auto(self, widget) :
-    
-        gtk.main_quit()
-        argv = ["disk-manager-root", "-b"]
-        sys.exit(os.spawnvp(os.P_WAIT, "disk-manager-root", argv))
-
-    def open_wizard(self, *args) :
-        ''' Execute AddWizard as root '''
-        
-        gtk.main_quit()
-        argv = ["disk-manager-root", "-a"]
-        sys.exit(os.spawnvp(os.P_WAIT, "disk-manager-root", argv))
-
